/v1/projects/{project_id}/iou/vms/{vm_id}/initial_config — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Iou »

# /v1/projects/{project_id}/iou/vms/{vm_id}/initial_config

Contents

- /v1/projects/{project_id}/iou/vms/{vm_id}/initial_config
  - GET /v1/projects/{project_id}/iou/vms/{vm_id}/initial_config
    - Response status codes
    - Output
    - Sample session

## GET /v1/projects/{project_id}/iou/vms/{vm_id}/initial_config

Retrieve the initial config content

### Response status codes

- 200: Initial config retrieved
- 400: Invalid request
- 404: Instance doesn’t exist

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
content | ✔ | ['string', 'null'] | Content of the initial configuration file

### Sample session

    curl -i -X GET 'http://localhost:8000/projects/{project_id}/iou/vms/{vm_id}/initial_config'

    GET /projects/{project_id}/iou/vms/{vm_id}/initial_config HTTP/1.1

    HTTP/1.1 200
    CONNECTION: keep-alive
    CONTENT-LENGTH: 25
    CONTENT-TYPE: application/json
    DATE: Thu, 08 Jan 2015 16:09:15 GMT
    SERVER: Python/3.4 GNS3/1.3.dev1
    X-ROUTE: /v1/projects/{project_id}/iou/vms/{vm_id}/initial_config

    {
        "content": "TEST"
    }

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Iou »